Zope.org

# Welcome to Zope.org The Web Site for the Zope Community Zope is an open source application server for building content management systems, intranets, portals, and custom applications. The Zope community consists of hundreds of companies and thousands of developers all over the world, working on building the platform and Zope applications. Zope is written in Python, a highly-productive, object-oriented scripting language. more ## Zope for...
New Users Introduction To Zope, About Python Web Masters Using Apache, Security, ZPT, DTML | Product Developers Developers Guide, Unit Testing Zope Developers Content Management Framework (CMF), Products, Using CVS/SVN, Bug Days
## What You can do on Zope.org Membership gives you your own home folder on Zope.org where you can create and manage your own Zope objects. The objects you create and maintain will be available to all people who visit Zope.org. Site visitors can find your content using the site search or by browsing your member folder. Many pages on the zope.org site are generated by search queries - by providing metadata such as keywords with your content it can appear in automated site pages such as product or news listings. more ## Zope Training ... Send your Zope training announcements to webmaster@zope.org ## Plone Training ... Send your Plone training announcements to webmaster@zope.org

��� | ������������������������������������������������������������������������������������������ ��������������������������� OMRON Corporation